.. :changelog:

History
-------

0.0.1 (11-11-2021)
---------------------

* First code creation


0.1.0 (26-11-2021)
------------------

* First official release.


0.1.1 (02-12-2021)
------------------

* Additional details added to export of accounts. Instead of only the energy label, it now includes the number of findings per severity


0.1.2 (06-12-2021)
------------------

* Added allow/deny function for regions


0.1.3 (06-12-2021)
------------------

* Updated library version


0.1.4 (09-12-2021)
------------------

* Allow to export to the root of an S3 bucket


0.2.0 (14-12-2021)
------------------

* Bumped awsenergylabelerlib and added logic for exporting finding resource data and finding type data


0.3.0 (31-01-2022)
------------------

* Introduced single account mode and exporting of metrics only
